@@ -25,7 +25,7 @@ from telegram import InputMessageContent
 class InputLocationMessageContent(InputMessageContent):
     """Base class for Telegram InputLocationMessageContent Objects"""
 
-    def __init__(self, latitude, longitude):
+    def __init__(self, latitude, longitude, **kwargs):
         # Required
         self.latitude = latitude
         self.longitude = longitude
