@@ -17,15 +17,13 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-
 """This module contains a object that represents a Telegram Message."""
 
 from datetime import datetime
 from time import mktime
 
-from telegram import (Audio, Contact, Document, Chat, Location, PhotoSize,
-                      Sticker, TelegramObject, User, Video, Voice, Venue,
-                      MessageEntity)
+from telegram import (Audio, Contact, Document, Chat, Location, PhotoSize, Sticker, TelegramObject,
+                      User, Video, Voice, Venue, MessageEntity)
 
 
 class Message(TelegramObject):
@@ -39,8 +37,10 @@ class Message(TelegramObject):
         from_user (:class:`telegram.User`):
         date (:class:`datetime.datetime`):
         forward_from (:class:`telegram.User`):
+        forward_from_chat (:class:`telegram.Chat`):
         forward_date (:class:`datetime.datetime`):
         reply_to_message (:class:`telegram.Message`):
+        edit_date (:class:`datetime.datetime`):
         text (str):
         audio (:class:`telegram.Audio`):
         document (:class:`telegram.Document`):
@@ -78,8 +78,10 @@ class Message(TelegramObject):
 
     Keyword Args:
         forward_from (Optional[:class:`telegram.User`]):
+        forward_from_chat (:class:`telegram.Chat`):
         forward_date (Optional[:class:`datetime.datetime`]):
         reply_to_message (Optional[:class:`telegram.Message`]):
+        edit_date (Optional[:class:`datetime.datetime`]):
         text (Optional[str]):
         audio (Optional[:class:`telegram.Audio`]):
         document (Optional[:class:`telegram.Document`]):
@@ -102,12 +104,7 @@ class Message(TelegramObject):
         channel_chat_created (Optional[bool]):
     """
 
-    def __init__(self,
-                 message_id,
-                 from_user,
-                 date,
-                 chat,
-                 **kwargs):
+    def __init__(self, message_id, from_user, date, chat, **kwargs):
         # Required
         self.message_id = int(message_id)
         self.from_user = from_user
@@ -115,8 +112,10 @@ class Message(TelegramObject):
         self.chat = chat
         # Optionals
         self.forward_from = kwargs.get('forward_from')
+        self.forward_from_chat = kwargs.get('forward_from_chat')
         self.forward_date = kwargs.get('forward_date')
         self.reply_to_message = kwargs.get('reply_to_message')
+        self.edit_date = kwargs.get('edit_date')
         self.text = kwargs.get('text', '')
         self.entities = kwargs.get('entities', list())
         self.audio = kwargs.get('audio')
@@ -135,12 +134,10 @@ class Message(TelegramObject):
         self.new_chat_photo = kwargs.get('new_chat_photo')
         self.delete_chat_photo = bool(kwargs.get('delete_chat_photo', False))
         self.group_chat_created = bool(kwargs.get('group_chat_created', False))
-        self.supergroup_chat_created = bool(kwargs.get(
-            'supergroup_chat_created', False))
+        self.supergroup_chat_created = bool(kwargs.get('supergroup_chat_created', False))
         self.migrate_to_chat_id = int(kwargs.get('migrate_to_chat_id', 0))
         self.migrate_from_chat_id = int(kwargs.get('migrate_from_chat_id', 0))
-        self.channel_chat_created = bool(kwargs.get('channel_chat_created',
-                                                    False))
+        self.channel_chat_created = bool(kwargs.get('channel_chat_created', False))
         self.pinned_message = kwargs.get('pinned_message')
 
     @property
@@ -165,9 +162,10 @@ class Message(TelegramObject):
         data['chat'] = Chat.de_json(data.get('chat'))
         data['entities'] = MessageEntity.de_list(data.get('entities'))
         data['forward_from'] = User.de_json(data.get('forward_from'))
+        data['forward_from_chat'] = Chat.de_json(data.get('forward_from_chat'))
         data['forward_date'] = Message._fromtimestamp(data.get('forward_date'))
-        data['reply_to_message'] = \
-            Message.de_json(data.get('reply_to_message'))
+        data['reply_to_message'] = Message.de_json(data.get('reply_to_message'))
+        data['edit_date'] = Message._fromtimestamp(data.get('edit_date'))
         data['audio'] = Audio.de_json(data.get('audio'))
         data['document'] = Document.de_json(data.get('document'))
         data['photo'] = PhotoSize.de_list(data.get('photo'))
@@ -203,6 +201,8 @@ class Message(TelegramObject):
         # Optionals
         if self.forward_date:
             data['forward_date'] = self._totimestamp(self.forward_date)
+        if self.edit_date:
+            data['edit_date'] = self._totimestamp(self.edit_date)
         if self.photo:
             data['photo'] = [p.to_dict() for p in self.photo]
         if self.entities:
